import { Component, OnInit } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule, Validators } from '@angular/forms';
import { loadStripe, Stripe } from '@stripe/stripe-js';

@Component({
  selector: 'app-deposit',
  standalone: true,
  imports: [
    ReactiveFormsModule,
  ],
  templateUrl: './deposit.component.html',
  styleUrl: './deposit.component.css'
})
export class DepositComponent implements OnInit{
  protected form = new FormGroup({amount: new FormControl(50, [Validators.min(50)])});
  private stripe: Stripe | null;

  async ngOnInit() {
    this.stripe = await loadStripe('pk_test_51');
  }

  submit() {
    if (this.stripe) {
      fetch('/backend/deposit/checkout', {
        method: 'POST',
        body: JSON.stringify(this.form.value),
      }).then(response => response.json()).then(response => {
        this.stripe?.redirectToCheckout({sessionId: response.sessionId});
      });
    }
  }
}
